/*
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.car.settings.enterprise;

import static android.car.test.mocks.AndroidMockitoHelper.syncCallOnMainThread;

import static com.google.common.truth.Truth.assertWithMessage;

import static org.mockito.Mockito.never;
import static org.mockito.Mockito.verify;

import android.content.res.XmlResourceParser;

import androidx.fragment.app.FragmentActivity;

import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;

public final class EnterprisePrivacySettingsFragmentTest extends BaseEnterpriseTestCase {

    private EnterprisePrivacySettingsFragment mFragment;

    @Mock
    private FragmentActivity mFragmentActivity;

    @Before
    public void setFragment() throws Exception {
        mFragment = syncCallOnMainThread(() -> new EnterprisePrivacySettingsFragment());
    }

    @Test
    public void testGetPreferenceScreenResId() {
        int resId = mFragment.getPreferenceScreenResId();

        XmlResourceParser parser = mRealContext.getResources().getXml(resId);
        assertWithMessage("xml with id %s", resId).that(parser).isNotNull();
    }

    @Test
    public void testFinishActivityWhenDeviceOwnerIsNotSet() {
        mockNotManaged();

        mFragment.onAttach(mSpiedContext, mFragmentActivity);

        verify(mFragmentActivity).finish();
    }

    @Test
    public void testDoesNotFinishActivityWhenDeviceOwnerIsNotSet() {
        mockDeviceOwner();

        mFragment.onAttach(mSpiedContext, mFragmentActivity);

        verify(mFragmentActivity, never()).finish();
    }
}
